@@ -49,6 +49,9 @@ class TestConfig:
         # Path to Ghostscript
         self.gs = None # type: Optional[Path]
 
+        # Path to Linux `perf` tool
+        self.perf_path = None # type: Optional[Path]
+
         # Run tests requiring Haddock
         self.haddock = False
 
@@ -127,9 +130,18 @@ class TestConfig:
         # Do we have profiling support?
         self.have_profiling = False
 
+        # Do we have profiling dynamic support?
+        self.have_profiling_dynamic = False
+
         # Do we have interpreter support?
         self.have_interp = False
 
+        # Are we cross-compiling?
+        self.cross = False
+        
+        # Does the RTS linker only support loading shared libraries?
+        self.interp_force_dyn = False
+
         # Do we have RTS linker?
         self.have_RTS_linker = False
 
@@ -154,7 +166,7 @@ class TestConfig:
         self.ghc_has_smp = True
 
         # Does the target have SMP support?
-        self.target_has_smp = True
+        self.target_has_smp = False
 
         # Is gdb available?
         self.have_gdb = False
@@ -182,8 +194,6 @@ class TestConfig:
         self.threads = 1
 
         # An optional executable used to wrap target code execution
-        # When set tests which aren't marked with TestConfig.cross_okay
-        # are skipped.
         self.target_wrapper = None
 
         # tests which should be considered to be broken during this testsuite
@@ -223,6 +233,10 @@ class TestConfig:
         # I have no idea what this does
         self.package_conf_cache_file = None # type: Optional[Path]
 
+        # the libdir for the test compiler. Set by hadrian, see
+        # Setting.Builders.RunTest
+        self.libdir = ''
+
         # The extra hadrian dependencies we need for all configured tests
         self.hadrian_deps = set() # type: Set[str]
 
@@ -441,6 +455,9 @@ class TestOptions:
        # Extra normalisation for compiler error messages
        self.extra_errmsg_normaliser = lambda x: x
 
+       # Extra normalisation for .prof files
+       self.extra_prof_normaliser = lambda x: x
+
        # Keep profiling callstacks.
        self.keep_prof_callstacks = False
 
@@ -453,6 +470,7 @@ class TestOptions:
        self.combined_output = False
 
        # How should the timeout be adjusted on this test?
+       self.pre_cmd_timeout_multiplier = 1.0
        self.compile_timeout_multiplier = 1.0
        self.run_timeout_multiplier = 1.0
 
@@ -463,15 +481,12 @@ class TestOptions:
        # Should we copy the files of symlink the files for the test?
        self.copy_files = False
 
-       # Should the test be run in a cross-compiled tree?
-       #   None:  infer from test function
-       #   True:  run when --target-wrapper is set
-       #   False: do not run in cross-compiled trees
-       self.cross_okay = None # type: Optional[bool]
-
        # The extra hadrian dependencies we need for this particular test
        self.hadrian_deps = set(["test:ghc"]) # type: Set[str]
 
+       # Record these `perf-events` counters when compiling this test, if `perf` is available
+       self.compiler_perf_counters = [] # type: List[str]
+
    @property
    def testdir(self) -> Path:
        if self.testdir_raw is None:
