@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# Language UndecidableInstances, DataKinds, TypeOperators, PolyKinds,
              TypeFamilies, GADTs, LambdaCase, ScopedTypeVariables #-}
 
@@ -10,8 +9,8 @@ import Data.Proxy
 data Fn a b where
   IdSym :: Fn Type Type
 
-type family
-  (@@) (f::Fn k k') (a::k)::k' where
+type (@@) :: Fn k k' -> k -> k'
+type family f @@ a where
   IdSym @@ a = a
 
 data KIND = X | FNARR KIND KIND
@@ -20,19 +19,20 @@ data TY :: KIND -> Type where
   ID    :: TY (FNARR X X)
   FNAPP :: TY (FNARR k k') -> TY k -> TY k'
 
-data TyRep (kind::KIND) :: TY kind -> Type where
+type TyRep :: forall (kind::KIND) -> TY kind -> Type
+data TyRep k t where
   TID    :: TyRep (FNARR X X)  ID
   TFnApp :: TyRep (FNARR k k') f
          -> TyRep k            a
          -> TyRep k'           (FNAPP f a)
 
-type family
-  IK (kind::KIND) :: Type where
+type IK :: KIND -> Type
+type family IK k where
   IK X            = Type
   IK (FNARR k k') = Fn (IK k) (IK k')
 
-type family
-  IT (ty::TY kind) :: IK kind where
+type IT :: TY kind -> IK kind
+type family IT t where
   IT ID          = IdSym
   IT (FNAPP f x) = IT f @@ IT x
 
