@@ -2,6 +2,7 @@
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE TypeFamilies #-}
+{-# LANGUAGE TypeAbstractions #-}
 module T16391a where
 
 import Data.Kind
@@ -9,7 +10,8 @@ import Data.Kind
 type Const (a :: Type) (b :: Type) = a
 type family F :: Const Type a where
   F = Int
-type TS = (Int :: Const Type a)
+type TS :: forall a . Const Type a
+type TS @a = (Int :: Const Type a)
 data T1 :: Const Type a where
   MkT1 :: T1
 data T2 :: Const Type a -> Type where
