@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE GADTs, PolyKinds, RankNTypes #-}
 
 module GADTVars where
@@ -6,5 +5,6 @@ module GADTVars where
 import Data.Kind
 import Data.Proxy
 
-data T (k1 :: Type) (k2 :: Type) (a :: k2) (b :: k2) where
+type T :: Type -> forall (k2 :: Type) -> k2 -> k2 -> Type
+data T k1 k2 a b where
   MkT :: T x1 Type (Proxy (y :: x1), z) z
