@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE DataKinds #-}
@@ -14,7 +13,8 @@ class Generic a where
 class PGeneric a where
   type To a (x :: Rep a) :: a
 
-type family MDefault (x :: a) :: a where
+type MDefault :: a -> a
+type family MDefault x where
   MDefault x = To (M x)
 
 class C a where
