@@ -10,5 +10,5 @@ module T15825 where
 
 type C k = (forall (x::k). *)
 
-class                       X (a :: *)
-instance forall (a :: C k). X (a :: *)
+class                         X (a :: *)
+instance forall k (a :: C k). X (a :: *)
