@@ -19,7 +19,7 @@ foreign import ccall unsafe "head_bytearray"
 foreign import ccall unsafe "head_bytearray"
   c_head_bytearray_b :: MyArray# -> IO Word8
 
-newtype MyArray# :: TYPE 'UnliftedRep where
+newtype MyArray# :: TYPE ('BoxedRep 'Unlifted) where
   MyArray# :: MutableByteArray# RealWorld -> MyArray#
 
 data MutableByteArray :: Type where
@@ -41,7 +41,6 @@ readByteArray (MutableByteArray b#) (I# i#) = IO $ \s0 ->
 -- set to the 105.
 luckySingleton :: IO MutableByteArray
 luckySingleton = IO $ \s0 -> case newByteArray# 1# s0 of
-  (# s1, marr# #) -> case writeWord8Array# marr# 0# 105## s1 of
+  (# s1, marr# #) -> case writeWord8Array# marr# 0# lit105 s1 of
     s2 -> (# s2, MutableByteArray marr# #)
-
-
+  where W8# lit105 = 105
