@@ -1,6 +1,6 @@
 module Main where
 
-import DynFlags
+import GHC.Driver.Session
 
 import Control.Monad
 import Data.List (isPrefixOf)
