@@ -9,21 +9,21 @@ import Data.Kind
 import Data.Proxy
 
 data family Nat :: k -> k -> Type
-newtype instance Nat :: (k -> Type) -> (k -> Type) -> Type where
+newtype instance Nat :: forall k . (k -> Type) -> (k -> Type) -> Type where
   Nat :: (forall xx. f xx -> g xx) -> Nat f g
 
 type family   F :: Maybe a
-type instance F = (Nothing :: Maybe a)
+type instance F @a = (Nothing :: Maybe a)
 
 class C k where
   data CD :: k -> k -> Type
   type CT :: k
 
 instance C (Maybe a) where
-  data CD :: Maybe a -> Maybe a -> Type where
+  data CD @(Maybe a) :: Maybe a -> Maybe a -> Type where
     CD :: forall a (m :: Maybe a) (n :: Maybe a). Proxy m -> Proxy n -> CD m n
-  type CT = (Nothing :: Maybe a)
+  type CT @(Maybe a) = (Nothing :: Maybe a)
 
 class Z k where
   type ZT :: Maybe k
-  type ZT = (Nothing :: Maybe k)
+  type ZT @k = (Nothing :: Maybe k)
