@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# Language UndecidableInstances, DataKinds, TypeOperators, TypeFamilies,
              PolyKinds, GADTs, LambdaCase, ScopedTypeVariables #-}
 
@@ -17,17 +16,20 @@ data TY :: KIND -> Type where
   ID    :: TY (FNARR X X)
   FNAPP :: TY (FNARR k k') -> TY k -> TY k'
 
-data TyRep (kind::KIND) :: TY kind -> Type where
+type TyRep :: forall (kind::KIND) -> TY kind -> Type
+data TyRep k t where
   TID    :: TyRep (FNARR X X)  ID
   TFnApp :: TyRep (FNARR k k') f
          -> TyRep k            a
          -> TyRep k'           (FNAPP f a)
 
-type family IK (kind::KIND) :: Type where
+type IK :: KIND -> Type
+type family IK k where
   IK X            = Type
   IK (FNARR k k') = IK k ~> IK k'
 
-type family IT (ty::TY kind) :: IK kind
+type IT :: TY kind -> IK kind
+type family IT t
 
 zero :: TyRep X a -> IT a
 zero x = case x of
