@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TypeApplications #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE PolyKinds #-}
@@ -10,19 +9,27 @@ import Data.Kind
 type family ConstType1 (a :: Type) :: Type where
   ConstType1 _ = Type
 
-type family F1 (x :: ConstType1 a) :: Type where
+type F1 :: ConstType1 a -> Type
+type family F1 x where
   F1 @a (x :: ConstType1 a) = a
-type family F2 (x :: ConstType1 a) :: ConstType1 a where
+
+type F2 :: ConstType1 a -> ConstType1 a
+type family F2 x where
   F2 @a (x :: ConstType1 a) = x :: ConstType1 a
+
 type F3 (x :: ConstType1 a) = a
 type F4 (x :: ConstType1 a) = x :: ConstType1 a
 
 type ConstType2 (a :: Type) = Type
 
-type family G1 (x :: ConstType2 a) :: Type where
+type G1 :: ConstType2 a -> Type
+type family G1 x where
   G1 @a (x :: ConstType2 a) = a
-type family G2 (x :: ConstType2 a) :: ConstType2 a where
+
+type G2 :: ConstType2 a -> Type
+type family G2 x where
   G2 @a (x :: ConstType2 a) = x :: ConstType1 a
+
 type G3 (x :: ConstType2 a) = a
 type G4 (x :: ConstType2 a) = x :: ConstType2 a
 
