@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE RankNTypes, GADTs, TypeOperators, PolyKinds, DataKinds, TypeFamilies, AllowAmbiguousTypes, UndecidableInstances #-}
 
 module T14246 where
@@ -7,7 +6,8 @@ import Data.Kind
 
 data Nat = Z | S Nat
 
-data Vect :: Nat -> Type -> Type where
+type Vect :: Nat -> Type -> Type
+data Vect n a where
   Nil  :: Vect Z a
   Cons :: a -> Vect n a -> Vect (S n) a
 
@@ -15,10 +15,12 @@ data Label a = Label a
 
 data L
 
-type family KLN (n :: k) :: Nat where
+type KLN :: k -> Nat
+type family KLN n where
     KLN (f :: v -> k) = S (KLN (forall t. f t))
     KLN (f :: Type) = Z
 
-type family Reveal (n :: k) (l :: Vect (KLN n) L) :: Type where
+type Reveal :: forall k. forall (n :: k) -> Vect (KLN n) L -> Type
+type family Reveal n l where
     Reveal (f :: v -> k) (Cons (Label (t :: v)) l) = Reveal (f t) l
     Reveal (a :: Type) Nil = a
