@@ -1,7 +1,7 @@
 {-# LANGUAGE PatternSynonyms #-}
 module Main (main) where
 
-import GHC.Tuple
+import GHC.Tuple (Solo (MkSolo), getSolo)
 
 type OneTuple = Solo
 
@@ -9,7 +9,7 @@ only :: OneTuple a -> a
 only = getSolo
 
 pattern OneTuple :: a -> Solo a
-pattern OneTuple a = Solo a
+pattern OneTuple a = MkSolo a
 
 main :: IO ()
 main = print (only (OneTuple 'x'))
