@@ -12,7 +12,7 @@ import GHC (GhcPs)
 
 testMe :: HsExpr GhcPs -> Int
 testMe (HsVar a b) = _
-testMe (HsUnboundVar xuv uv) = _
+testMe (HsHole a) = _
 testMe (HsOverLabel xol m_ip) = _
 testMe (HsIPVar xv hin) = _
 testMe (HsOverLit xole hol) = _
