@@ -2,7 +2,7 @@ module HsUtils where
 import GHC.Hs.Binds
 import GHC.Types.SrcLoc
 
-addPatSynSelector:: LHsBind p -> [a]
+addPatSynSelector:: GenLocated l (HsBindLR idL idR) -> [a]
 addPatSynSelector bind
   | PatSynBind _ _ <- unLoc bind
   = []
