@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE KindSignatures #-}
@@ -25,5 +24,6 @@ data instance In (F f) r o where
   MkIn :: In f (Sum1 r (In (F f) r)) o -> In (F f) r o
 
 -- Requires polymorphic recursion
-data In' (f :: Code i o) :: (i -> Type) -> o -> Type where
+type In' :: Code i o -> (i -> Type) -> o -> Type
+data In' f r t where
   MkIn' :: In' g (Sum1 r (In' (F g) r)) t -> In' (F g) r t
