@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE RankNTypes #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE DataKinds #-}
@@ -10,4 +9,5 @@ import Data.Kind
 type Const a b = a
 data SameKind :: k -> k -> Type
 
-newtype T (k :: Const Type a) = MkT (forall (b :: k). SameKind a b)
+type T :: forall a. Const Type a -> Type
+newtype T @a k = MkT (forall (b :: k). SameKind a b)
