@@ -1,8 +1,6 @@
 {-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE CPP #-}
-#if __GLASGOW_HASKELL__ >= 703
 {-# LANGUAGE Safe #-}
-#endif
 module SafeLang18 where
 
 #define p377 toPair
@@ -12,4 +10,3 @@ data StrictPair a b = !a :*: !b
 toPair :: StrictPair a b -> (a, b)
 toPair (x :*: y) = (x, y)
 {-# INLINE p377 #-}
-
