@@ -1,7 +1,7 @@
 {-# LANGUAGE MagicHash #-}
 module T7287 where
 
-import GHC.Prim
+import GHC.Exts
 
 {-# RULES
   "int2Word#/word2Int#" forall x. int2Word# (word2Int# x) = x
