@@ -6,7 +6,7 @@ module T13098 where
 
 import Language.Haskell.TH
 
-$( sequence [ dataD (cxt []) (mkName "T") [PlainTV (mkName "a") ()]
+$( sequence [ dataD (cxt []) (mkName "T") [PlainTV (mkName "a") BndrReq]
                      Nothing [normalC (mkName "T") []] []
           , pragCompleteD [mkName "T"] Nothing ] )
 
