@@ -19,5 +19,26 @@ type family F a b where
 wob :: forall a b. (Q [F a b], R b a) => a -> Int
 wob = undefined
 
-g :: forall a. Q [a] => [a] -> Int
-g x = wob x
+g :: forall c. Q [c] => [c] -> Int
+g x = wob x   -- Instantiate wob @[c] @beta
+
+{- Constraint solving for g
+
+[G] Q [c]
+[W] Q [F [c] beta]   -- Do NOT fire Q [x] instance
+[W] R beta [c]
+--> instance for R
+[G] Q [c]
+[W] Q [F [c] beta]
+[W] beta ~ c
+-->
+[G] Q [c]
+[W] Q [F [c] c]
+--> Eqn for F
+[G] Q [c]
+[W] Q [c]
+--> done
+
+c ~ F [c] beta
+
+-}
