@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE ScopedTypeVariables, TypeOperators, DataKinds, PolyKinds,
              TypeFamilies, GADTs, StandaloneDeriving #-}
 
@@ -18,7 +17,8 @@ data Vec :: Type -> Nat -> Type where
   (:>) :: a -> Vec a n -> Vec a (Succ n)
 infixr 5 :>
 
-type family (xs :: Vec a n) +++ (ys :: Vec a m) :: Vec a (n + m) where
+type (+++) :: Vec a n -> Vec a m -> Vec a (n + m)
+type family xs +++ ys where
   VNil +++ ys = ys
   (x :> xs) +++ ys = x :> (xs +++ ys)
 infixr 5 +++
