@@ -4,4 +4,4 @@ import Language.Haskell.TH.Lib
 import Language.Haskell.TH.Syntax
 
 ueqT :: Q Type
-ueqT = conT $ mkNameG_tc "ghc-prim" "GHC.Prim" "~#"
+ueqT = conT $ mkNameG_tc "ghc-internal" "GHC.Internal.Prim" "~#"
