@@ -9,4 +9,4 @@ module T18640a where
 import Data.Kind
 
 type F2 :: forall a b. Type -> a
-type family F2 :: forall b. Type -> Type where
+type family F2 @a :: forall b. Type -> Type where
