@@ -1,3 +1,4 @@
+{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds, UnicodeSyntax #-}
 {-# OPTIONS -Wno-star-is-type #-}
 
@@ -28,9 +29,12 @@ main = do
   print $ typeOf (Proxy :: Proxy [1,2,3])
   print $ typeOf (Proxy :: Proxy 'EQ)
   print $ typeOf (Proxy :: Proxy TYPE)
-  print $ typeOf (Proxy :: Proxy (TYPE 'LiftedRep))
+  print $ typeOf (Proxy :: Proxy (TYPE ('BoxedRep 'Lifted)))
   print $ typeOf (Proxy :: Proxy *)
   print $ typeOf (Proxy :: Proxy ★)
-  print $ typeOf (Proxy :: Proxy 'LiftedRep)
+  print $ typeOf (Proxy :: Proxy ('BoxedRep 'Lifted))
+  print $ typeOf (Proxy :: Proxy 'Lifted)
+  print $ typeOf (Proxy :: Proxy 'Unlifted)
+  print $ typeOf (Proxy :: Proxy LiftedRep)
   print $ typeOf (Proxy :: Proxy '(1, "hello"))
   print $ typeOf (Proxy :: Proxy (~~))
