@@ -7,6 +7,11 @@
 --
 -- Apr 20: Works again.  NB: the ImpredicativeTypes flag
 --
+-- July 20: Fails again.  Under Quick Look this now fails, because
+--          we don't have a special typing rule for ExplicitTuples
+--          We could, and it would improve the typing for tuple sections.
+--          But for now I'm just letting it fail, until someone yells.
+--
 -- The test was added by Max in 5e8ff849, apparently to test tuple sections
 
 module Main where
@@ -17,4 +22,5 @@ e = (,"Hello" ++ "World",)
 dropFunction :: (a, String, forall c. c -> c -> c) -> (a, String, Int)
 dropFunction (x, y, z) = (x, y, z 10 20)
 
-main = print (dropFunction $ e "Meh" (flip const), dropFunction $ e 10 const)
+main = print ( dropFunction (e "Meh" (flip const))
+             , dropFunction (e 10 const))
